# Changelog

## [0.1.2](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/compare/v0.1.1...v0.1.2) (2025-10-20)


### Bug Fixes

* python build ([#6](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/issues/6)) ([860e1ff](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/commit/860e1ff365af224015af038246978dbf35658600))

## [0.1.1](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/compare/v0.1.0...v0.1.1) (2025-10-20)


### Bug Fixes

* update scheduler interface ([#4](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/issues/4)) ([d61750b](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/commit/d61750b2bf97559532ec695ca0405f4d8b9fbf85))

## 0.1.0 (2025-10-20)


### Features

* trigger first release ([#2](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/issues/2)) ([f890cfb](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/commit/f890cfb180cba1c53df6ece02ac112096df91caa))
